@@ -52,6 +52,8 @@ namespace
         Arg::LongOption("no-lines"),
 
         Arg::LongOption("no-parse-member"), // options only
+
+        {"no-decoration", 'D'},
         {"own-debug", Arg::None},
         {"own-tokens", 'T'},
         {"parsefun-skeleton", 'P'},         
@@ -86,7 +88,7 @@ namespace
 int main(int argc, char **argv)
 try
 {
-    Arg &arg = Arg::initialize("AB:b:C:c:f:H:hI:i:M:m:n:p:P:s:S:tTVv", 
+    Arg &arg = Arg::initialize("AB:b:C:c:Df:H:hI:i:M:m:n:p:P:s:S:tTVv", 
                     longOptions, longEnd, argc, argv);
 
     arg.versionHelp(usage, version, 1);
@@ -140,6 +142,9 @@ try
 
     Generator generator(rules, parser.polymorphic());
 
+    if (generator.conflicts())
+        return 1;
+
     generator.baseClassHeader();
     generator.classHeader();
     generator.implementationHeader();
