@@ -19,6 +19,7 @@ class Generator
 {
     typedef void (Generator::*Inserter)(std::ostream &) const;
     typedef std::unordered_map<std::string, Inserter>     Map;
+
     typedef Map::value_type                     MapValue;
     typedef Map::const_iterator                 MapConstIter;
 
@@ -33,6 +34,7 @@ class Generator
     std::string const &d_nameSpace;
     std::string const &d_matchedTextFunction;
     std::string const &d_tokenFunction;
+    std::string d_nameSpacedClassname;
 
     mutable std::string d_key;          // extracted at $insert statements
     mutable size_t d_indent;
@@ -46,19 +48,24 @@ class Generator
     mutable Writer d_writer;                // maintains its own const-ness
 
     static Map s_insert;
-    static char const *s_baseFlag;          // text to change to the class 
-                                            // name
-    static size_t const s_baseFlagSize;     // # of characters in s_baseFlag
+    static char const *s_atFlag;            // \@ flag in skeletons
 
-    static char const *s_namespaceBaseFlag; // text to change to the 
-                                            // namespace + class name
-    static size_t const s_namespaceBaseFlagSize;    // # of characters 
+    struct At;
+    struct AtBool;
 
+    typedef std::vector<At> AtVector;
+
+    struct AtBool;
+    typedef std::vector<AtBool> AtBoolVector;
+
+    static AtBoolVector s_atBol;     // no typo: Bol = Begin of line
+    static AtVector s_at;
 
     public:
         Generator(Rules const &rules, 
              std::unordered_map<std::string, std::string> const &polymorphic); 
 
+        bool conflicts() const;
         void baseClassHeader() const;
         void classHeader() const;
         void implementationHeader() const;
@@ -75,10 +82,9 @@ class Generator
                                                     // called, just before the
                                                     // generated code 
 
-        void warnExisting(std::string const &fileName, 
-                          std::string const &option,
-                          std::string const &expectedOptionValue,
-                          std::string const &regex) const;
+        bool errExisting(std::string const &fileName, 
+                         std::string const &option,
+                         std::string const &regex) const;
         bool grep(std::string const &fileName, std::string const &regex) 
                                                                         const;
 
@@ -105,7 +111,6 @@ class Generator
         void namespaceOpen(std::ostream &out) const;
         void namespaceUse(std::ostream &out) const;
         void polymorphic(std::ostream &out) const;
-        void polymorphicImpl(std::ostream &out) const;
         void polymorphicInline(std::ostream &out) const;
         void polymorphicSpecializations(std::ostream &out) const;
         void preIncludes(std::ostream &out) const;
@@ -118,10 +123,36 @@ class Generator
         void threading(std::ostream &out) const;
         void tokens(std::ostream &out) const;
 
+        void ifInsertStype(bool &accept) const;
+        void ifPrintTokens(bool &accept) const;
+        void ifLtype(bool &accept) const;
+        void ifThreadSafe(bool &accept) const;
+        void atElse(bool &accept) const;
+        void atEnd(bool &accept) const;
+
+        std::string const &atTokenFunction() const;
+        std::string const &atMatchedTextFunction() const;
+        std::string const &atLtype() const;
+        std::string const &atNameSpacedClassname() const;
+        std::string const &atClassname() const;
+
+        void replaceBaseFlag(std::string &line) const;
+        void replaceAtKey(std::string &line, size_t pos) const;
+
         static void selectSymbolic(Terminal const *terminal, 
                                    Terminal::ConstVector &symbolicTokens);
         static void replace(std::string &str, char ch, 
                        std::string const &replacement);
+        void insert(std::ostream &out, size_t indent, char const *skel) const;
+        void bolAt(std::ostream &out, std::string &line, std::istream &in,
+                                                        bool &accept) const;
+
+        template <typename AtType> 
+        typename std::vector<AtType>::const_iterator find(
+            std::string const &line, 
+            size_t pos, 
+            std::vector<AtType> const &atVector
+        ) const;
 };
 
 #endif
