@@ -1,6 +1,6 @@
 #include "item.ih"
 
-Item::Item(Production const *production, size_t/*unsigned*/ dot)
+Item::Item(Production const *production, size_t dot)
 :
     d_production(production),
     d_dot(dot)
