@@ -158,6 +158,7 @@ class Options
         std::string const &scannerInclude() const;
         std::string const &scannerMatchedTextFunction() const;
         std::string const &scannerTokenFunction() const;
+        std::string const &skeletonDirectory() const;
         std::string const &stype() const;
 
         static std::string undelimit(std::string const &str);
@@ -168,7 +169,9 @@ class Options
             // called by setAccessorVariables()
         void setBooleans();
         void setBasicStrings();
-        std::string setOpt(char const *opt, std::string const &defaultSpec);
+        void setOpt(std::string *destVar, char const *opt, 
+                    std::string const &defaultSpec);
+
         void setQuotedStrings();
         void setPathStrings();  // called by setAccessorVariables,
                                 // called by parser.cleanup(). 
@@ -202,6 +205,11 @@ inline std::string const &Options::baseClassHeader() const
     return d_baseClassHeader;
 }
 
+inline std::string const &Options::skeletonDirectory() const
+{
+    return d_skeletonDirectory;
+}
+
 inline std::string const &Options::baseClassSkeleton() const
 {
     return d_baseClassSkeleton;
