@@ -146,15 +146,10 @@ class State
 
         static void initialState();
         static State &newState();
-        static void nextState(Next &next, State &state);
-        static bool hasKernel(State const *state, Item::Vector const &kernel);
 
-        static void staticAddKernelItem(Item const &item, State &state);
-
-        static void staticCheckConflicts(State *state);   // calls inline:
+        void nextState(Next &next);
+        bool hasKernel(Item::Vector const &kernel) const;
         void checkConflicts();
-
-        static void staticSummarizeActions(State *state);  // calls inline:
         void summarizeActions();
 
         struct LookaheadContext 
@@ -166,14 +161,9 @@ class State
             StateItem::Vector::iterator childKernel;
         };
         static void distributeLA(Next &next, LookaheadContext &context);
-
-        static void updateLA(size_t itemIdx, 
-                             LookaheadContext &context);
+        static void updateLA(size_t itemIdx, LookaheadContext &context);
 
         void propagateLA(); // propagate the LA's over the State's items.
-        static void staticPropagateLA(State *state);  
-                                                // called from the non-static
-                                                // function
 };
 
 inline int State::type() const
